@@ -1,5 +1,5 @@
 /* This file is part of the Zebra server.
-   Copyright (C) 1994-2010 Index Data
+   Copyright (C) 1994-2011 Index Data
 
 Zebra is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -24,6 +24,9 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  * concatenating the tag names at each level.
  */
 
+#if HAVE_CONFIG_H
+#include <config.h>
+#endif
 #include <yaz/wrbuf.h>
 #include <idzebra/data1.h>
 
