@@ -1,5 +1,5 @@
 /* This file is part of the Zebra server.
-   Copyright (C) 1994-2010 Index Data
+   Copyright (C) 1994-2011 Index Data
 
    Zebra is free software; you can redistribute it and/or modify it under
    the terms of the GNU General Public License as published by the Free
@@ -19,6 +19,9 @@
 
 
 
+#if HAVE_CONFIG_H
+#include <config.h>
+#endif
 #include <sys/types.h>
 #include <fcntl.h>
 #if HAVE_UNISTD_H
