@@ -1,5 +1,5 @@
 /* This file is part of the Zebra server.
-   Copyright (C) 1994-2010 Index Data
+   Copyright (C) 1994-2011 Index Data
 
 Zebra is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -76,6 +76,15 @@ Record rec_get(Records p, zint sysno);
     \returns record pointer (or NULL on error)
 */
 Record rec_get_root(Records p);
+
+
+/** \brief gets next record - with given records
+    \param p records handle
+    \param rec record
+    \returns record pointer (or NULL on error)
+*/
+Record rec_get_next(Records p, Record rec);
+
 ZEBRA_RES rec_close (Records *p);
 
 /** \brief opens records system
