@@ -1,5 +1,5 @@
 /* This file is part of the Zebra server.
-   Copyright (C) 1994-2010 Index Data
+   Copyright (C) 1994-2011 Index Data
 
 Zebra is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -17,6 +17,9 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 */
 
+#if HAVE_CONFIG_H
+#include <config.h>
+#endif
 #include <sys/types.h>
 #include <assert.h>
 #include <stdlib.h>
@@ -995,7 +998,7 @@ static void zebraExplain_writeCategoryList(ZebraExplainInfo zei,
     assert(zcl);
     if (!zcl->dirty)
 	return ;
-    zcl->dirty = 1;
+    zcl->dirty = 0;
     node_categoryList = zcl->data1_categoryList;
 
 #if ZINFO_DEBUG
